import { pxToRem } from '@guardian/src-foundations/utils';

// The theme file is based on the specification at https://system-ui.com/theme
var space = [0, 4, 8, 12, 16, 20, 24, 36, 48, 96];
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [320, 375, 480, 660];

var breakpoints$1 = {
  mobile: tweakpoints[0],
  mobileMedium: tweakpoints[1],
  mobileLandscape: tweakpoints[2],
  phablet: tweakpoints[3],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

var space$1 = {
  1: space[1],
  2: space[2],
  3: space[3],
  4: space[4],
  5: space[5],
  6: space[6],
  9: space[7],
  12: space[8],
  24: space[9]
};
/* TODO: this should be exposed as a number instead of a string,
   so consumers can perform calculations on it */

var remSpace = {
  1: "".concat(pxToRem(space$1[1]), "rem"),
  2: "".concat(pxToRem(space$1[2]), "rem"),
  3: "".concat(pxToRem(space$1[3]), "rem"),
  4: "".concat(pxToRem(space$1[4]), "rem"),
  5: "".concat(pxToRem(space$1[5]), "rem"),
  6: "".concat(pxToRem(space$1[6]), "rem"),
  9: "".concat(pxToRem(space$1[9]), "rem"),
  12: "".concat(pxToRem(space$1[12]), "rem"),
  24: "".concat(pxToRem(space$1[24]), "rem")
};

// babel * typescript * rollup = ¯\_(ツ)_/¯

var minWidth = function minWidth(from) {
  return "@media (min-width: ".concat("".concat(from, "px"), ")");
};

var maxWidth = function maxWidth(until) {
  return "@media (max-width: ".concat("".concat(until - 1, "px"), ")");
};

var minWidthMaxWidth = function minWidthMaxWidth(from, until) {
  return "@media (min-width: ".concat("".concat(from, "px"), ") and (max-width: ", "".concat(until - 1, "px"), ")");
}; // e.g. from.*


var from = {
  mobile: minWidth(breakpoints$1.mobile),
  mobileMedium: minWidth(breakpoints$1.mobileMedium),
  mobileLandscape: minWidth(breakpoints$1.mobileLandscape),
  phablet: minWidth(breakpoints$1.phablet),
  tablet: minWidth(breakpoints$1.tablet),
  desktop: minWidth(breakpoints$1.desktop),
  leftCol: minWidth(breakpoints$1.leftCol),
  wide: minWidth(breakpoints$1.wide)
}; // e.g. until.*

var until = {
  mobile: maxWidth(breakpoints$1.mobile),
  mobileMedium: maxWidth(breakpoints$1.mobileMedium),
  mobileLandscape: maxWidth(breakpoints$1.mobileLandscape),
  phablet: maxWidth(breakpoints$1.phablet),
  tablet: maxWidth(breakpoints$1.tablet),
  desktop: maxWidth(breakpoints$1.desktop),
  leftCol: maxWidth(breakpoints$1.leftCol),
  wide: maxWidth(breakpoints$1.wide)
}; // e.g. between.*.and.*

var between = {
  mobile: {
    and: {
      mobileMedium: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.mobileMedium),
      mobileLandscape: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.mobileLandscape),
      phablet: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobile, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.wide)
    }
  },
  mobileMedium: {
    and: {
      mobileLandscape: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.mobileLandscape),
      phablet: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.wide)
    }
  },
  mobileLandscape: {
    and: {
      phablet: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.wide)
    }
  },
  phablet: {
    and: {
      tablet: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.wide)
    }
  },
  tablet: {
    and: {
      desktop: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.wide)
    }
  },
  desktop: {
    and: {
      leftCol: minWidthMaxWidth(breakpoints$1.desktop, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.desktop, breakpoints$1.wide)
    }
  },
  leftCol: {
    and: {
      wide: minWidthMaxWidth(breakpoints$1.leftCol, breakpoints$1.wide)
    }
  }
};

export { between, breakpoints$1 as breakpoints, from, until };
